==> hoteldruid-mod-de_1.3.2-1.tar.gz: de/modifica_ospiti.php <==
<?php

switch ($messaggio) {

case "Modifica gli ospiti della prenotazione":           $messaggio = "G&auml;stebuchung &auml;ndern"; break;
case "Cliente titolare":                                 $messaggio = "Titel"; break;
case "Ospite della prenotazione":                        $messaggio = "G&auml;ste der Buchung"; break;
case "nato il":                                          $messaggio = "born the"; break;
case "nata il":                                          $messaggio = "born the"; break;
case "CAP":                                              $messaggio = "PLZ"; break;
case "Telefono":                                         $messaggio = "Telefon"; break;
case "2º telefono":                                     $messaggio = "Telefon tags&uuml;ber"; break;
case "3º telefono":                                     $messaggio = "Telefon abends"; break;
case "Cognome":                                          $messaggio = "Vorname"; break;
case "nome":                                             $messaggio = "Name"; break;
case "sesso":                                            $messaggio = "Geschlecht"; break;
case "Data di nascita":                                  $messaggio = "Geburtstag"; break;
case "anno con 4 cifre":                                 $messaggio = "Jahr 4-stellig"; break;
case "Documento":                                        $messaggio = "Dokument"; break;
case "scadenza":                                         $messaggio = "expiration"; break;
case "Altri ospiti":                                     $messaggio = "Weitere G&auml;ste"; break;
case "Modifica gli ospiti":                              $messaggio = "G&auml;ste &auml;ndern"; break;
case "Torna indietro":                                   $messaggio = "zur&uuml;ck"; break;
case "Gli ospiti della prenotazione":                    $messaggio = "Reservierung G&auml;steliste"; break;
case "sono stati modificati":                            $messaggio = "wurden ge&auml;ndert"; break;
case "nato":                                             $messaggio = "geboren"; break;
case "nata":                                             $messaggio = "geborn"; break;
case "il":                                               $messaggio = "der"; break;
case " a":                                               $messaggio = " in"; break;
case "scade":                                            $messaggio = "Endet"; break;
case "cittadinanza":                                     $messaggio = "Nationalit&auml;t"; break;
case "città di nascita":                                $messaggio = "Geburtsort"; break;
case "reg./prov. di nascita":                            $messaggio = "Geburtsregion"; break;
case "nazione di nascita":                               $messaggio = "Nationalit&auml;t"; break;
case "reg./prov.":                                       $messaggio = "Region"; break;
case "nazione":                                          $messaggio = "nation"; break;
case "Nazione":                                          $messaggio = "Nation"; break;
case "rilasciato da":                                    $messaggio = "ausgestellt durch"; break;
case "nazione di rilascio":                              $messaggio = "releasing nation"; break;
case "Ospite principale":                                $messaggio = "Principal G&auml;ste"; break;
case "Parentela":                                        $messaggio = "wohnhaft in"; break;
case "parentela":                                        $messaggio = "wohnhaft in"; break;
case "Codice fiscale":                                   $messaggio = "Steuernummer"; break;
case "città":                                           $messaggio = "Ort"; break;
case "Partita iva":                                      $messaggio = "UstId."; break;
case "Modifica gli ospiti delle prenotazioni":           $messaggio = "Modify guests of reservations"; break;
case "della prenotazione":                               $messaggio = "of reservation"; break;
case "Gli ospiti delle prenotazioni":                    $messaggio = "The guests of reservations"; break;
case "ln.":  					$messaggio = "ln."; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-de_2.1.2-1.tar.gz: de/modifica_ospiti.php <==
<?php

switch ($messaggio) {

case "Modifica gli ospiti della prenotazione":           $messaggio = "G&auml;stebuchung &auml;ndern"; break;
case "Cliente titolare":                                 $messaggio = "Titel"; break;
case "Ospite della prenotazione":                        $messaggio = "G&auml;ste der Buchung"; break;
case "CAP":                                              $messaggio = "PLZ"; break;
case "Telefono":                                         $messaggio = "Telefon"; break;
case "2º telefono":                                      $messaggio = "Telefon tags&uuml;ber"; break;
case "3º telefono":                                      $messaggio = "Telefon abends"; break;
case "Cognome":                                          $messaggio = "Vorname"; break;
case "nome":                                             $messaggio = "Name"; break;
case "sesso":                                            $messaggio = "Geschlecht"; break;
case "Data di nascita":                                  $messaggio = "Geburtstag"; break;
case "anno con 4 cifre":                                 $messaggio = "Jahr 4-stellig"; break;
case "Documento":                                        $messaggio = "Dokument"; break;
case "Altri ospiti":                                     $messaggio = "Weitere G&auml;ste"; break;
case "Modifica gli ospiti":                              $messaggio = "G&auml;ste &auml;ndern"; break;
case "Torna indietro":                                   $messaggio = "zur&uuml;ck"; break;
case "Gli ospiti della prenotazione":                    $messaggio = "Reservierung G&auml;steliste"; break;
case "sono stati modificati":                            $messaggio = "wurden ge&auml;ndert"; break;
case "nato":                                             $messaggio = "geboren"; break;
case "nata":                                             $messaggio = "geborn"; break;
case "il":                                               $messaggio = "der"; break;
case " a":                                               $messaggio = " in"; break;
case "scade":                                            $messaggio = "Endet"; break;
case "cittadinanza":                                     $messaggio = "Nationalit&auml;t"; break;
case "città di nascita":                                 $messaggio = "Geburtsort"; break;
case "reg./prov. di nascita":                            $messaggio = "Geburtsregion"; break;
case "nazione di nascita":                               $messaggio = "Nationalit&auml;t"; break;
case "reg./prov.":                                       $messaggio = "Region"; break;
case "rilasciato da":                                    $messaggio = "ausgestellt durch"; break;
case "nazione di rilascio":                              $messaggio = "ausstellendes Land"; break;
case "Ospite principale":                                $messaggio = "Hauptgast"; break;
case "Parentela":                                        $messaggio = "wohnhaft in"; break;
case "parentela":                                        $messaggio = "wohnhaft in"; break;
case "Codice fiscale":                                   $messaggio = "Steuernummer"; break;
case "città":                                            $messaggio = "Ort"; break;
case "Partita iva":                                      $messaggio = "UstId."; break;
case "Modifica gli ospiti delle prenotazioni":           $messaggio = "G&auml;ste der Reservierung &auml;ndern"; break;
case "della prenotazione":                               $messaggio = "der Reservierung"; break;
case "Gli ospiti delle prenotazioni":                    $messaggio = "Die G&auml;ste der Reservierung"; break;
case "ln.":  					         $messaggio = "ln."; break;
case "nato il":  				$messaggio = "born the"; break;
case "nata il":  				$messaggio = "born the"; break;
case "scadenza":  				$messaggio = "expiration"; break;
case "nazione":  				$messaggio = "nation"; break;
case "Nazione":  				$messaggio = "Nation"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
